#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
THIS FILE IS PART OF AZUR LANE TOOL BY MATT BELFAST BROWN
mode_KSN_Com.py - The core mode of the Azur Lane Tool.

Author: Matt Belfast Brown
Create Date: 2019-07-11
Version Date: 2024-01-06
Version: 0.6.4
Mode Create Date: 2020-10-07
Mode Date: 2024-01-06
Mode Version: 1.2.0

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2019-2024 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program.  If not,
see <http://www.gnu.org/licenses/>.
"""


# define function
def fun_ksen_nmco(vari_ksip: str) -> str:
    """
    此函数用于查询修正过后的舰船名称.
    This function is used to query harmonious ship names including Japanese and American ships.
    :param vari_ksip: 查询内容. Query content.
    :return: vari_knrs - 查询结果. Search result.
    """
    if vari_ksip not in list_ksnc + list_ksnm:

        vari_knrs = "查找内容无效，请检验输入内容，或检查更新！"
    else:
        vari_knrs = ""
        for para_lsor in range(len(list_ksnm)):
            if vari_ksip == list_ksnm[para_lsor]:
                vari_knrs = "舰船原名：" + vari_ksip + "，修正名称:" + list_ksnc[para_lsor]
                break
            elif vari_ksip == list_ksnc[para_lsor]:
                vari_knrs = "舰船原名：" + list_ksnm[para_lsor] + "，修正名称:" + vari_ksip
                break
            else:
                vari_knrs = "查找内容无效，请检验输入内容，或检查更新！"
    return vari_knrs


# define list
list_ksnm = ["峰风", "神风", "朝风", "春风", "松风", "旗风", "追风", "朝凪", "夕凪", "睦月", "如月", "卯月", "水无月",
             "文月", "长月", "三日月", "吹雪", "白雪", "初雪", "深雪", "浦波", "绫波", "敷波", "曙", "涟", "潮", "晓",
             "响", "雷", "电", "初春", "若叶", "初霜", "有明", "夕暮", "白露", "时雨", "夕立", "海风", "山风", "江风",
             "凉风", "朝潮", "大潮", "满潮", "荒潮", "霞", "阳炎", "不知火", "黑潮", "亲潮", "初风", "雪风", "天津风",
             "浦风", "矶风", "滨风", "谷风", "野分", "岚", "萩风", "舞风", "夕云", "卷云", "风云", "长波", "卷波", "清波",
             "秋月", "初月", "凉月", "新月", "若月", "冬月", "春月", "宵月", "满月", "花月", "岛风", "樫野", "天龙",
             "龙田", "球磨", "北上", "大井", "长良", "五十铃", "名取", "由良", "鬼怒", "阿武隈", "夕张", "川内", "神通",
             "那珂", "阿贺野", "能代", "矢矧", "酒匂", "大淀", "古鹰", "加古", "青叶", "衣笠", "最上", "三隈", "铃谷",
             "熊野", "利根", "筑摩", "妙高", "那智", "足柄", "羽黑", "高雄", "爱宕", "摩耶", "鸟海", "金刚", "比叡",
             "榛名", "雾岛", "天城", "敷岛", "三笠", "扶桑", "山城", "伊势", "日向", "长门", "陆奥", "土佐", "纪伊",
             "尾张", "骏河", "大和", "武藏", "凤翔", "龙骧", "祥凤", "瑞凤", "千岁", "千代田", "大鲸", "龙凤", "飞鹰",
             "隼鹰", "赤城", "加贺", "苍龙", "飞龙", "翔鹤", "瑞鹤", "大凤", "云龙", "葛城", "信浓", "白龙", "明石",
             "伊吹", "出云", "北风", "吾妻", "四万十", "云仙", "伊9", "伊13", "伊16", "伊19", "伊25", "伊26", "伊54",
             "伊56", "伊58", "伊60", "伊168", "伊490", "Z1", "Z2", "Z5", "Z9", "Z11", "Z12", "Z13", "Z16", "Z17", "Z18",
             "Z19", "Z20", "Z21", "Z22", "Z23", "Z24", "Z25", "Z26", "Z28", "Z35", "Z36", "Z46", "Z47", "奥托·冯·阿尔文斯莱本",
             "菲利克斯·舒尔茨", "埃姆登", "埃尔宾", "德累斯顿", "皮劳", "德弗林格尔", "柯尼斯堡", "卡尔斯鲁厄", "科隆",
             "莱比锡", "纽伦堡", "马格德堡", "雷根斯堡", "美因茨", "约克", "德意志", "斯佩伯爵海军上将", "舍尔海军上将",
             "希佩尔海军上将", "欧根亲王", "布吕歇尔", "海因里希亲王", "阿达尔伯特亲王", "罗恩", "兴登堡", "埃吉尔",
             "塞德利茨", "吕佐夫", "格奈森瑙", "沙恩霍斯特", "布伦希尔德", "奥丁", "鲁普雷希特亲王", "图林根", "赫尔戈兰",
             "俾斯麦", "提尔比茨", "腓特烈大帝", "乌尔里希·冯·胡滕", "齐柏林伯爵", "彼得·史特拉塞", "奥古斯特·冯·帕塞瓦尔",
             "亚德", "易北", "威悉", "U-37", "U-47", "U-73", "U-81", "U-96", "U-101", "U-110", "U-410", "U-522", "U-556",
             "U-557", "U-1206", "衣阿华", "新泽西", "旧金山", "博伊西", "提康德罗加", "巴劳鱵", "射水鱼", "莫里森",
             "圣地亚哥", "英格拉罕", "哈尔滨", "让·巴尔", "扎拉"]
list_ksnc = ["樱", "榊", "櫂", "橪", "棡", "樋", "椎", "桎", "枳", "松", "樟", "楙", "杌", "橗", "枨", "檧", "桐", "杉",
             "杨", "梧", "朴", "柚", "柿", "棪", "槿", "槟", "枫", "栀", "梓", "柏", "梅", "楉", "檨", "榎", "棭", "梿",
             "栴", "椿", "菪", "杣", "茳", "莨", "棹", "荙", "樠", "栘", "蕸", "萩", "蒲", "蓉", "藮", "菙", "莲", "菡",
             "槆", "柉", "樇", "栭", "苓", "萍", "莵", "蒠", "茭", "荨", "枟", "苌", "棬", "棈", "椛", "檚", "栎", "枥",
             "若", "㮔", "桸", "楛", "槾", "榵", "芒", "㭴", "豺", "豹", "熊", "狸", "獾", "貊", "貉", "猽", "㹨", "猤",
             "貃", "狐", "貆", "貎", "豻", "豼", "貅", "貁", "貄", "淀", "狼", "狌", "犹", "猅", "猨", "狻", "狺", "猁",
             "猑", "狘", "獌", "狏", "狳", "犰", "獒", "犬", "犮", "猋", "鲤", "鲟", "鲑", "鳗", "鳐", "鲙", "鲐", "魟",
             "鲼", "鳌", "螯", "鲨", "鲛", "䲠", "鲣", "鳂", "鲪", "鲸", "鳄", "凤", "枭", "鹞", "鹳", "鹂", "鹃", "迖",
             "鸗", "鸱", "鸢", "凰", "鸾", "蛟", "龙", "鹬", "鹤", "鹩", "靇", "鹖", "鵗", "鹫", "茗", "峦", "侌", "苝",
             "猉", "虒", "猃", "玖", "十纱", "伊知梦", "衣玖", "双叶檎", "双叶梦", "冴诗", "冴梦", "冴矢", "六重",
             "伊吕波", "诗玖玲", "莉泽洛特", "格尔达", "保拉", "沃尔特劳", "贝尔纳黛特", "埃丽卡", "埃丝特", "弗蕾德贡",
             "迪特琳德", "汉娜", "赫尔米娜", "卡洛琳", "威尔赫米娜", "安妮特", "妮米", "妮丝", "妮可", "妮露", "妮娅",
             "咪菓", "咪露", "希露", "希娜", "奥莉薇娅·冯·阿诺德", "弗郎西斯卡·舒伯特", "埃玛", "埃尔薇菈", "迪特林德",
             "宝拉", "多萝泰娅", "阿尔伯缇娜", "夏璐尔", "克劳迪亚", "莉普莎", "诺菈", "马格达莱娜", "瑞吉娜", "米兹",
             "伊冯娜", "亚勒玛妮亚", "休贝塔伯爵", "席勒", "芙兰希卡", "萨沃伊亲王", "布丽吉特", "赫莉米娜亲王",
             "阿德莉娅亲王", "艾伯塔", "希尔德加德", "埃格妮丝", "桑德菈", "露西", "奥古斯塔", "格尔林德", "贝尔莎",
             "沃登", "蕾贝卡亲王", "特鲁德", "赫娜洛蕾", "奥德莉亚", "阿尔芙莉达", "腓德雷卡大帝", "乌尔里克·冯·胡贝尔",
             "海拉伯爵", "佩特菈·斯坦贝瑟", "奥斯特雷德·冯·帕赫贝尔", "阿黛尔", "埃尔斯贝特", "威尔玛", "优米娜", "优希娜",
             "优娜米", "优哈依", "优玖露", "优伊欧伊", "优伊伊丽", "优斯伊丽", "优柯妮妮", "优可可洛", "优可可娜",
             "优伊妮欧露", "霍克艾", "花园", "雾城", "树城", "卡莉永", "鱵", "喷水鱼", "塞普拉斯", "圣戴安娜", "格拉哈姆",
             "滨江", "简·布罗伊", "扎达尔"]
